@@ -16,7 +16,7 @@ class CIDClient:
     __access_token = None
 
     __graphql_env_endpoints = {
-        'dev': 'https://m752xzraej.execute-api.us-east-2.amazonaws.com/dev/graphql',
+        'dev': 'https://pkynkv5pck.execute-api.us-east-2.amazonaws.com/dev/graphql',
         'prod': 'https://o56dder9y3.execute-api.us-east-2.amazonaws.com/prod/graphql',
         'sandbox': 'http://0.0.0.0:5000/graphql',
     }
